@@ -422,12 +422,204 @@ count_goals_shots <- function(play_by_play) {
   play_by_play[, c(keep[seq_len(after)], insert, keep[(after + 1L):length(keep)])]
 }
 
+#' Calculate event-to-event deltas and speeds in normalized x/y, distance, and angle for a play-by-play
+#'
+#' `calculate_speed()` calculates event-to-event deltas and speeds in normalized x/y, distance, and angle for a play-by-play.
+#'
+#' @inheritParams add_on_ice_players
+#' @returns data.frame with one row per event (play) and added columns: `dXN`, `dYN`, `dD`, `dA`, `dT`, `dXNdT`, `dYNdT`, `dDdT`, `dAdT`
+#' @export
+
+calculate_speed <- function(play_by_play) {
+  t <- play_by_play$secondsElapsedInGame
+  x <- play_by_play$xCoordNorm
+  y <- play_by_play$yCoordNorm
+  n <- nrow(play_by_play)
+  dXN <- rep(NA_real_, n)
+  dYN <- rep(NA_real_, n)
+  dD  <- rep(NA_real_, n)
+  dA  <- rep(NA_real_, n)
+  dT  <- rep(NA_real_, n)
+  dXNdT <- rep(NA_real_, n)
+  dYNdT <- rep(NA_real_, n)
+  dDdT  <- rep(NA_real_, n)
+  dAdT  <- rep(NA_real_, n)
+  is_faceoff <- play_by_play$typeDescKey == 'faceoff'
+  for (g in unique(play_by_play$gameId)) {
+    idx <- which(play_by_play$gameId == g)
+    idx <- idx[order(t[idx], play_by_play$sortOrder[idx], na.last = TRUE)]
+    if (length(idx) <= 1L) next
+    m <- length(idx)
+    valid_spatial <- !is.na(x[idx]) & !is.na(y[idx]) &
+      !is.na(play_by_play$distance[idx]) & !is.na(play_by_play$angle[idx])
+    prev_pos <- rep(NA_integer_, m)
+    last_valid_since_faceoff <- NA_integer_
+    for (k in seq_len(m)) {
+      i <- idx[k]
+      if (k == 1L) {
+        prev_pos[k] <- NA_integer_
+      } else if (is_faceoff[i]) {
+        prev_pos[k] <- k - 1L
+      } else {
+        prev_pos[k] <- last_valid_since_faceoff
+      }
+      if (is_faceoff[i]) {
+        last_valid_since_faceoff <- if (valid_spatial[k]) k else NA_integer_
+      } else if (valid_spatial[k]) {
+        last_valid_since_faceoff <- k
+      }
+    }
+    curr_k <- which(!is.na(prev_pos))
+    if (!length(curr_k)) next
+    curr <- idx[curr_k]
+    prev <- idx[prev_pos[curr_k]]
+    dt <- t[curr] - t[prev]
+    dx <- x[curr] - x[prev]
+    dy <- y[curr] - y[prev]
+    dd <- play_by_play$distance[curr] - play_by_play$distance[prev]
+    da <- play_by_play$angle[curr]    - play_by_play$angle[prev]
+    dT[curr]  <- dt
+    dXN[curr] <- dx
+    dYN[curr] <- dy
+    dD[curr]  <- dd
+    dA[curr]  <- da
+    ok <- !is.na(dt) & dt >= 0
+    j  <- which(ok)
+    if (length(j)) {
+      cc <- curr[j]
+      denom <- dt[j]
+      denom[denom == 0] <- 0.5
+      dXNdT[cc] <- dx[j] / denom
+      dYNdT[cc] <- dy[j] / denom
+      dDdT[cc]  <- dd[j] / denom
+      dAdT[cc]  <- da[j] / denom
+    }
+  }
+  play_by_play$dXN   <- dXN
+  play_by_play$dYN   <- dYN
+  play_by_play$dD    <- dD
+  play_by_play$dA    <- dA
+  play_by_play$dT    <- dT
+  play_by_play$dXNdT <- dXNdT
+  play_by_play$dYNdT <- dYNdT
+  play_by_play$dDdT  <- dDdT
+  play_by_play$dAdT  <- dAdT
+  after  <- match('angle', names(play_by_play))
+  insert <- c('dXN', 'dYN', 'dD', 'dA', 'dT', 'dXNdT', 'dYNdT', 'dDdT', 'dAdT')
+  nms    <- names(play_by_play)
+  play_by_play[, c(nms[seq_len(after)], insert, setdiff(nms[-seq_len(after)], insert))]
+}
+
+#' Add shooter biometrics to (a) play-by-play(s)
+#'
+#' `add_shooter_biometrics()` adds shooter biometrics (height, weight, age at game date, and onwing/offwing/neutral side) to (a) play-by-play(s) for Fenwick events.
+#'
+#' @inheritParams add_on_ice_players
+#' @param neutral_threshold integer; absolute yCoordNorm at or below which `shooterSide` is set to 'neutral'
+#' @returns data.frame with one row per event (play) and added columns: `shooterHeight`, `shooterWeight`, `shooterAge`, `shooterSide`
+#' @export
+
+add_shooter_biometrics <- function(play_by_play, neutral_threshold = 5) {
+  bios  <- players()
+  games <- games()
+  shooterId <- ifelse(!is.na(play_by_play$scoringPlayerId), play_by_play$scoringPlayerId, play_by_play$shootingPlayerId)
+  is_block <- play_by_play$typeDescKey == 'blocked-shot'
+  shooterId[is_block] <- NA
+  gidx <- match(play_by_play$gameId, games$gameId)
+  gd   <- as.Date(games$gameDate[gidx])
+  pidx <- match(shooterId, bios$playerId)
+  ht   <- bios$height[pidx]
+  wt   <- bios$weight[pidx]
+  hand <- bios$handCode[pidx]
+  pos  <- bios$positionCode[pidx]
+  bd   <- as.Date(bios$birthDate[pidx])
+  gy   <- as.integer(format(gd, '%Y'))
+  by   <- as.integer(format(bd, '%Y'))
+  gm   <- as.integer(format(gd, '%m'))
+  bm   <- as.integer(format(bd, '%m'))
+  gD   <- as.integer(format(gd, '%d'))
+  bD   <- as.integer(format(bd, '%d'))
+  had_bday <- (gm > bm) | (gm == bm & gD >= bD)
+  age  <- (gy - by) - ifelse(had_bday, 0L, 1L)
+  age[is.na(gd) | is.na(bd)] <- NA_integer_
+  y    <- play_by_play$yCoordNorm
+  back <- play_by_play$shotType == 'backhand'
+  side <- rep(NA_character_, nrow(play_by_play))
+  has_shooter <- !is.na(shooterId)
+  neutral <- has_shooter & !is.na(y) & abs(y) <= neutral_threshold
+  side[neutral] <- 'neutral'
+  non_neutral <- has_shooter & !neutral & !is.na(y) & !is.na(hand)
+  r       <- non_neutral & hand == 'R'
+  l       <- non_neutral & hand == 'L'
+  off_f_r <- r & (y > 0)
+  off_f_l <- l & (y < 0)
+  off_b_r <- r & back & (y < 0)
+  off_b_l <- l & back & (y > 0)
+  off     <- (off_f_r | off_f_l) & !back
+  off     <- off | off_b_r | off_b_l
+  side[non_neutral] <- ifelse(off[non_neutral], 'offwing', 'onwing')
+  play_by_play$shooterHeight       <- ht
+  play_by_play$shooterWeight       <- wt
+  play_by_play$shooterAge          <- age
+  play_by_play$shooterSide         <- side
+  play_by_play$shooterPositionCode <- pos
+  play_by_play
+}
+
+#' Add goalie biometrics to (a) play-by-play(s)
+#'
+#' `add_goalie_biometrics()` adds goalie biometrics (height, weight, age at game date, and glove/blocker/neutral side) to (a) play-by-play(s) for Fenwick events.
+#'
+#' @inheritParams add_on_ice_players
+#' @param neutral_threshold integer; absolute yCoordNorm at or below which goalieSide is set to 'neutral'
+#' @returns data.frame with one row per event (play) and added columns: `goalieHeight`, `goalieWeight`, `goalieAge`, `goalieSide`
+#' @export
+
+add_goalie_biometrics <- function(play_by_play, neutral_threshold = 5) {
+  bios  <- players()
+  games <- games()
+  goalieId <- play_by_play$goalieInNetId
+  gidx <- match(play_by_play$gameId, games$gameId)
+  gd   <- as.Date(games$gameDate[gidx])
+  pidx <- match(goalieId, bios$playerId)
+  ht   <- bios$height[pidx]
+  wt   <- bios$weight[pidx]
+  hand <- bios$handCode[pidx]
+  bd   <- as.Date(bios$birthDate[pidx])
+  gy   <- as.integer(format(gd, '%Y'))
+  by   <- as.integer(format(bd, '%Y'))
+  gm   <- as.integer(format(gd, '%m'))
+  bm   <- as.integer(format(bd, '%m'))
+  gD   <- as.integer(format(gd, '%d'))
+  bD   <- as.integer(format(bd, '%d'))
+  had_bday <- (gm > bm) | (gm == bm & gD >= bD)
+  age <- (gy - by) - ifelse(had_bday, 0L, 1L)
+  age[is.na(gd) | is.na(bd)] <- NA_integer_
+  y <- play_by_play$yCoordNorm
+  side <- rep(NA_character_, nrow(play_by_play))
+  has_goalie <- !is.na(goalieId)
+  neutral <- has_goalie & !is.na(y) & abs(y) <= neutral_threshold
+  side[neutral] <- 'neutral'
+  non_neutral   <- has_goalie & !neutral & !is.na(y) & !is.na(hand)
+  l <- non_neutral & hand == 'L'
+  r <- non_neutral & hand == 'R'
+  glove <- rep(FALSE, nrow(play_by_play))
+  glove[l & (y > 0)] <- TRUE
+  glove[r & (y < 0)] <- TRUE
+  side[non_neutral]  <- ifelse(glove[non_neutral], 'glove', 'blocker')
+  play_by_play$goalieHeight <- ht
+  play_by_play$goalieWeight <- wt
+  play_by_play$goalieAge    <- age
+  play_by_play$goalieSide   <- side
+  play_by_play
+}
+
 #' Add on-ice player IDs to a play-by-play by merging with shift charts
 #' 
 #' `add_on_ice_players()` merges a play-by-play with a shift chart to determine which players are on the ice at each event. It adds home- and away-team on-ice player ID lists, as well as event-perspective for/against player ID lists when `isHome` is available.
 #' 
-#' @param play_by_play data.frame of shift chart rows; see [gc_play_by_play()], [gc_play_by_plays()], [wsc_play_by_play()], or [wsc_play_by_plays()] for reference; the original columns must exist
-#' @param shift_chart data.frame of shift chart rows; see [shift_chart()] or [shift_charts()] for reference; the original columns must exist
+#' @param play_by_play data.frame of play-by-play(s); see [gc_play_by_play()], [gc_play_by_plays()], [wsc_play_by_play()], or [wsc_play_by_plays()] for reference; the original columns must exist
+#' @param shift_chart data.frame of shift chart(s); see [shift_chart()] or [shift_charts()] for reference; the original columns must exist
 #' @returns data.frame with one row per event (play) and added list-columns:
 #' `homePlayerIds`, `awayPlayerIds`, `playerIdsFor`, and `playerIdsAgainst`
 #' @examples
@@ -437,51 +629,79 @@ count_goals_shots <- function(play_by_play) {
 
 add_on_ice_players <- function(play_by_play, shift_chart) {
   n           <- nrow(play_by_play)
-  home_ids    <- rep(list(integer()), n)
-  away_ids    <- rep(list(integer()), n)
-  for_ids     <- rep(list(integer()), n)
-  against_ids <- rep(list(integer()), n)
-  if (!('isHome' %in% names(shift_chart))) {
-    homeTeamId <- as.integer(names(which.max(table(
-      play_by_play$eventOwnerTeamId[play_by_play$isHome %in% TRUE & !is.na(play_by_play$eventOwnerTeamId)]
-    ))))
-    awayTeamId <- as.integer(names(which.max(table(
-      play_by_play$eventOwnerTeamId[play_by_play$isHome %in% FALSE & !is.na(play_by_play$eventOwnerTeamId)]
-    ))))
-    shift_chart$isHome <- ifelse(
-      shift_chart$teamId == homeTeamId,
-      TRUE,
-      ifelse(shift_chart$teamId == awayTeamId, FALSE, NA)
-    )
-  }
+  home_ids    <- rep(list(integer(0)), n)
+  away_ids    <- rep(list(integer(0)), n)
+  for_ids     <- rep(list(integer(0)), n)
+  against_ids <- rep(list(integer(0)), n)
+
   post_types <- c('period-start', 'faceoff')
-  use_post   <- play_by_play$typeDescKey %in% post_types
+  typeDescKey <- if ('typeDescKey' %in% names(play_by_play)) as.character(play_by_play$typeDescKey) else rep(NA_character_, n)
+  use_post   <- !is.na(typeDescKey) & typeDescKey %in% post_types
+
+  # Helpers for robust ordering
+  .ord_col <- function(df, nm, fallback) {
+    if (nm %in% names(df)) return(df[[nm]])
+    fallback
+  }
+
+  has_sc_isHome <- 'isHome' %in% names(shift_chart)
+
   for (g in unique(play_by_play$gameId)) {
     p_idx <- which(play_by_play$gameId == g)
     s_idx <- which(shift_chart$gameId == g)
     if (!length(p_idx) || !length(s_idx)) next
-    p_idx <- p_idx[order(
-      play_by_play$secondsElapsedInGame[p_idx],
-      play_by_play$sortOrder[p_idx],
-      na.last = TRUE
-    )]
-    sc <- shift_chart[s_idx, ]
-    sc <- sc[order(sc$startSecondsElapsedInGame, sc$endSecondsElapsedInGame, na.last = TRUE), ]
+
+    # Order plays within game (sortOrder may not exist in aggregated pbp)
+    t_play <- .ord_col(play_by_play, 'secondsElapsedInGame', rep(NA_real_, n))
+    so     <- .ord_col(play_by_play, 'sortOrder', play_by_play$eventId)
+    p_idx  <- p_idx[order(t_play[p_idx], so[p_idx], na.last = TRUE)]
+
+    sc <- shift_chart[s_idx, , drop = FALSE]
+    sc <- sc[order(sc$startSecondsElapsedInGame, sc$endSecondsElapsedInGame, na.last = TRUE), , drop = FALSE]
+
+    # Infer sc$isHome PER GAME if missing
+    if (!has_sc_isHome) {
+      # Need a per-game mapping from teamId -> home/away
+      # Use eventOwnerTeamId conditioned on pbp$isHome within this game
+      if (!('eventOwnerTeamId' %in% names(play_by_play)) || !('isHome' %in% names(play_by_play))) {
+        sc$isHome <- NA
+      } else {
+        eo  <- play_by_play$eventOwnerTeamId[p_idx]
+        ih  <- play_by_play$isHome[p_idx]
+
+        home_cand <- eo[ih %in% TRUE  & !is.na(eo)]
+        away_cand <- eo[ih %in% FALSE & !is.na(eo)]
+
+        homeTeamId <- if (length(home_cand)) as.integer(names(which.max(table(home_cand)))) else NA_integer_
+        awayTeamId <- if (length(away_cand)) as.integer(names(which.max(table(away_cand)))) else NA_integer_
+
+        sc$isHome <- ifelse(
+          !is.na(homeTeamId) & sc$teamId == homeTeamId,
+          TRUE,
+          ifelse(!is.na(awayTeamId) & sc$teamId == awayTeamId, FALSE, NA)
+        )
+      }
+    }
+
     for (team_home in c(TRUE, FALSE)) {
-      s_t <- sc[sc$isHome %in% team_home, ]
+      s_t <- sc[sc$isHome %in% team_home, , drop = FALSE]
       if (!nrow(s_t)) next
+
       starts <- s_t$startSecondsElapsedInGame
       ends   <- s_t$endSecondsElapsedInGame
       pids   <- s_t$playerId
+
       j_pre    <- 1L
       j_post   <- 1L
-      act_pre  <- integer()
-      end_pre  <- numeric()
-      act_post <- integer()
-      end_post <- numeric()
+      act_pre  <- integer(0)
+      end_pre  <- numeric(0)
+      act_post <- integer(0)
+      end_post <- numeric(0)
+
       for (i in p_idx) {
         t <- play_by_play$secondsElapsedInGame[i]
         if (is.na(t)) next
+
         while (j_pre <= length(starts) && starts[j_pre] < t) {
           pid <- pids[j_pre]
           en  <- ends[j_pre]
@@ -494,6 +714,7 @@ add_on_ice_players <- function(play_by_play, shift_chart) {
           }
           j_pre <- j_pre + 1L
         }
+
         while (j_post <= length(starts) && starts[j_post] <= t) {
           pid <- pids[j_post]
           en  <- ends[j_post]
@@ -506,6 +727,7 @@ add_on_ice_players <- function(play_by_play, shift_chart) {
           }
           j_post <- j_post + 1L
         }
+
         if (length(act_pre)) {
           keep    <- end_pre >= t
           act_pre <- act_pre[keep]
@@ -516,15 +738,20 @@ add_on_ice_players <- function(play_by_play, shift_chart) {
           act_post <- act_post[keep]
           end_post <- end_post[keep]
         }
+
         active <- if (use_post[i]) act_post else act_pre
+        active <- sort(unique(active))
+
         if (team_home) {
-          home_ids[i] <- list(sort(unique(active)))
+          home_ids[i] <- list(active)
         } else {
-          away_ids[i] <- list(sort(unique(active)))
+          away_ids[i] <- list(active)
         }
       }
     }
   }
+
+  # Build for/against from pbp$isHome
   for (i in seq_len(n)) {
     if (isTRUE(play_by_play$isHome[i])) {
       for_ids[i]     <- home_ids[i]
@@ -537,11 +764,14 @@ add_on_ice_players <- function(play_by_play, shift_chart) {
       against_ids[i] <- list(NULL)
     }
   }
-  is_ps_so <- play_by_play$situationCode %in% c('0101', '1010')
-  if (any(is_ps_so, na.rm = TRUE)) {
+
+  # Shootout override (player + goalie only)
+  situationCode <- if ('situationCode' %in% names(play_by_play)) as.character(play_by_play$situationCode) else rep(NA_character_, n)
+  is_ps_so <- !is.na(situationCode) & situationCode %in% c('0101', '1010')
+  if (any(is_ps_so)) {
     for (i in which(is_ps_so)) {
-      f <- if (is.na(play_by_play$shootingPlayerId[i])) integer() else as.integer(play_by_play$shootingPlayerId[i])
-      a <- if (is.na(play_by_play$goalieInNetId[i]))    integer() else as.integer(play_by_play$goalieInNetId[i])
+      f <- if (is.na(play_by_play$shootingPlayerId[i])) integer(0) else as.integer(play_by_play$shootingPlayerId[i])
+      a <- if (is.na(play_by_play$goalieInNetId[i]))    integer(0) else as.integer(play_by_play$goalieInNetId[i])
       for_ids[i]     <- list(f)
       against_ids[i] <- list(a)
       if (isTRUE(play_by_play$isHome[i])) {
@@ -553,12 +783,17 @@ add_on_ice_players <- function(play_by_play, shift_chart) {
       }
     }
   }
+
   play_by_play$homePlayerIds    <- home_ids
   play_by_play$awayPlayerIds    <- away_ids
   play_by_play$playerIdsFor     <- for_ids
   play_by_play$playerIdsAgainst <- against_ids
+
   insert <- c('homePlayerIds', 'awayPlayerIds', 'playerIdsFor', 'playerIdsAgainst')
   keep   <- setdiff(names(play_by_play), insert)
-  after  <- match('strengthState', keep)
+
+  after <- match('strengthState', keep)
+  if (is.na(after)) after <- length(keep)
+
   play_by_play[, c(keep[seq_len(after)], insert, keep[(after + 1L):length(keep)])]
 }
