@@ -1,6 +1,6 @@
 #' Access all the franchises
-#' 
-#' `franchises()` scrapes all the franchises.
+#'
+#' `franchises()` retrieves all the franchises as a `data.frame` where each row represents franchise and includes detail on team identity, affiliation, and matchup-side context.
 #'
 #' @returns data.frame with one row per franchise
 #' @examples
@@ -20,7 +20,11 @@ franchises <- function() {
     details$firstSeasonId    <- NULL
     details$mostRecentTeamId <- NULL
     details$teamAbbrev       <- NULL
-    merge(franchises[order(franchises$id), ], details, by = 'id')
+    franchises <- merge(franchises[order(franchises$id), ], details, by = 'id')
+    names(franchises)[names(franchises) == 'id']       <- 'franchiseId'
+    names(franchises)[names(franchises) == 'fullName'] <- 'franchiseFullName'
+    names(franchises) <- normalize_team_abbrev_cols(names(franchises))
+    franchises
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -28,10 +32,9 @@ franchises <- function() {
 }
 
 #' Access the all-time statistics for all the franchises by game type
-#' 
-#' `franchise_statistics()` scrapes the all-time statistics for all the 
-#' franchises by game type.
-#' 
+#'
+#' `franchise_statistics()` retrieves the all-time statistics for all the franchises by game type as a `data.frame` where each row represents franchise per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per franchise per game type
 #' @examples
 #' franchise_stats <- franchise_statistics()
@@ -44,6 +47,8 @@ franchise_statistics <- function() {
       type = 'r'
     )$data
     stats$id <- NULL
+    names(stats)[names(stats) == 'teamAbbrev'] <- 'teamTriCode'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
     stats[order(stats$franchiseId, stats$gameTypeId), ]
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
@@ -59,10 +64,9 @@ franchise_stats <- function() {
 }
 
 #' Access the all-time statistics for all the franchises by team and game type
-#' 
-#' `franchise_team_statistics()` scrapes the all-time statistics for all the 
-#' franchises by team and game type.
-#' 
+#'
+#' `franchise_team_statistics()` retrieves the all-time statistics for all the franchises by team and game type as a `data.frame` where each row represents team per franchise per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per team per franchise per game type
 #' @examples
 #' franchise_team_stats <- franchise_team_statistics()
@@ -75,6 +79,8 @@ franchise_team_statistics <- function() {
       type = 'r'
     )$data
     stats$id <- NULL
+    names(stats)[names(stats) == 'triCode'] <- 'teamTriCode'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
     stats[order(stats$franchiseId, stats$teamId, stats$gameTypeId), ]
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
@@ -90,10 +96,9 @@ franchise_team_stats <- function() {
 }
 
 #' Access the statistics for all the franchises by season and game type
-#' 
-#' `franchise_season_statistics()` scrapes the statistics for all the 
-#' franchises by season and game type.
-#' 
+#'
+#' `franchise_season_statistics()` retrieves the statistics for all the franchises by season and game type as a `data.frame` where each row represents franchise per season per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per franchise per season per game type
 #' @examples
 #' # May take >5s, so skip.
@@ -107,6 +112,8 @@ franchise_season_statistics <- function() {
       type = 'r'
     )$data
     stats$id <- NULL
+    names(stats)[names(stats) == 'triCode'] <- 'teamTriCode'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
     stats[order(stats$franchiseId, stats$seasonId, stats$gameTypeId), ]
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
@@ -123,10 +130,9 @@ franchise_season_stats <- function() {
 
 #' Access the all-time statistics versus other franchises for all the 
 #' franchises by game type
-#' 
-#' `franchise_versus_franchise()` scrapes the all-time statistics versus 
-#' other franchises for all the franchises by game type.
-#' 
+#'
+#' `franchise_versus_franchise()` retrieves the all-time statistics versus other franchises for all the franchises by game type as a `data.frame` where each row represents franchise per franchise per game type and includes detail on date/season filtering windows and chronological context plus team identity, affiliation, and matchup-side context.
+#'
 #' @returns data.frame with one row per franchise per franchise per game type
 #' @examples
 #' # May take >5s, so skip.
@@ -135,18 +141,20 @@ franchise_season_stats <- function() {
 
 franchise_versus_franchise <- function() {
   tryCatch({
-    versus <- nhl_api(
+    versus    <- nhl_api(
       path = 'all-time-record-vs-franchise',
       type = 'r'
     )$data
     versus$id <- NULL
-    versus[order(
+    versus    <- versus[order(
       versus$teamFranchiseId, 
       versus$teamId, 
       versus$opponentFranchiseId, 
       versus$opponentTeamId, 
       versus$gameTypeId
     ), ]
+    names(versus)[names(versus) == 'teamFranchiseId'] <- 'franchiseId'
+    versus
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -160,9 +168,8 @@ franchise_vs_franchise <- function() {
 }
 
 #' Access the playoff series results for all the franchises by situation
-#' 
-#' `franchise_playoff_situational_results()` scrapes the playoff series 
-#' results for all the franchises by situation.
+#'
+#' `franchise_playoff_situational_results()` retrieves the playoff series results for all the franchises by situation as a `data.frame` where each row represents franchise per situation and includes detail on team identity, affiliation, and matchup-side context.
 #'
 #' @returns data.frame with one row per franchise per situation
 #' @examples
