@@ -1,7 +1,7 @@
 #' Access the glossary
-#' 
-#' `glossary()` scrapes the glossary.
-#' 
+#'
+#' `glossary()` retrieves the glossary as a `data.frame` where each row represents terminology and includes detail on reference definitions and rules-framework information.
+#'
 #' @returns data.frame with one row per terminology
 #' @examples
 #' glossary <- glossary()
@@ -9,10 +9,13 @@
 
 glossary <- function() {
   tryCatch({
-    nhl_api(
+    terms <- nhl_api(
       path = 'en/glossary',
       type = 's'
     )$data
+    names(terms)[names(terms) == 'id']       <- 'terminologyId'
+    names(terms)[names(terms) == 'fullName'] <- 'terminologyFullName'
+    terms
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -20,9 +23,9 @@ glossary <- function() {
 }
 
 #' Access all the countries
-#' 
-#' `countries` scrapes all the countries.
-#' 
+#'
+#' `countries()` retrieves all the countries as a `data.frame` where each row represents country and includes detail on reference metadata, regional context, and media availability detail.
+#'
 #' @returns data.frame with one row per country
 #' @examples
 #' all_countries <- countries()
@@ -30,10 +33,13 @@ glossary <- function() {
 
 countries <- function() {
   tryCatch({
-    nhl_api(
+    countries <- nhl_api(
       path = 'en/country',
       type = 's'
     )$data
+    names(countries)[names(countries) == 'id']           <- 'countryId'
+    names(countries)[names(countries) == 'country3Code'] <- 'countryTriCode'
+    countries
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -41,10 +47,11 @@ countries <- function() {
 }
 
 #' Access the location for a zip code
-#' 
-#' `location()` scrapes the location for a given `zip` code.
-#' 
+#'
+#' `location()` retrieves the location for a zip code as a `data.frame` where each row represents team and includes detail on venue/location geography and regional metadata.
+#'
 #' @param zip integer (e.g., 48304)
+#'
 #' @returns data.frame with one row per team
 #' @examples
 #' Cranbrook_Schools <- location(48304)
@@ -58,6 +65,9 @@ location <- function(zip = 10001) {
         type = 'w'
       )
       location[0, ]
+      names(location)[names(location) == 'country'] <- 'countryCode'
+      names(location) <- normalize_locale_names(names(location))
+      names(location) <- normalize_team_abbrev_cols(names(location))
       location
     },
     error = function(e) {
@@ -68,9 +78,9 @@ location <- function(zip = 10001) {
 }
 
 #' Access all the streams
-#' 
-#' `streams()` scrapes all the streams.
-#' 
+#'
+#' `streams()` retrieves all the streams as a `data.frame` where each row represents stream and includes detail on reference metadata, regional context, and media availability detail.
+#'
 #' @returns data.frame with one row per stream
 #' @examples
 #' all_streams <- streams()
@@ -89,10 +99,11 @@ streams <- function() {
 }
 
 #' Access the NHL Network TV schedule for a date
-#' 
-#' `tv_schedule()` scrapes the NHL Network TV schedule for a given `date`.
-#' 
+#'
+#' `tv_schedule()` retrieves the NHL Network TV schedule for a date as a `data.frame` where each row represents program and includes detail on date/season filtering windows and chronological context.
+#'
 #' @inheritParams standings
+#'
 #' @returns data.frame with one row per program
 #' @examples
 #' tv_schedule_Halloween_2025 <- tv_schedule(date = '2025-10-31')
