@@ -1,8 +1,7 @@
 #' Access the configurations for skater reports
-#' 
-#' `skater_report_configurations()` scrapes the configurations for 
-#' [skater_season_report()] and [skater_game_report()].
-#' 
+#'
+#' `skater_report_configurations()` retrieves the configurations for skater reports as a nested `list` that separates summary and detail blocks for production, workload, efficiency, and result-level performance outcomes, situational splits across home/road, strength state, and overtime/shootout states, and configuration catalogs for valid report categories and filters.
+#'
 #' @returns list with various items
 #' @examples
 #' skater_report_configs <- skater_report_configurations()
@@ -29,13 +28,13 @@ skater_report_configs <- function() {
 
 #' Access various reports for a season, game type, and category for all 
 #' the skaters by season
-#' 
-#' `skater_season_report()` scrapes various reports for a given set of 
-#' `season`, `game_type`, and `category` for all the skaters by season.
-#' 
+#'
+#' `skater_season_report()` retrieves various reports for a season, game type, and category for all the skaters by season as a `data.frame` where each row represents player and includes detail on date/season filtering windows and chronological context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @inheritParams roster_statistics
 #' @param category character (e.g., 'puckPossessions'); see 
 #' [skater_report_configurations()] for reference
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' # May take >5s, so skip.
@@ -68,7 +67,10 @@ skater_season_report <- function(
         ),
         type  = 's'
       )$data
-      report[order(report$playerId), ]
+      report <- report[order(report$playerId), ]
+      names(report)[names(report) == 'lastName'] <- 'skaterLastName'
+      names(report) <- normalize_team_abbrev_cols(names(report))
+      report
     },
     error = function(e) {
       message('Invalid argument(s); refer to help file.')
@@ -79,11 +81,11 @@ skater_season_report <- function(
 
 #' Access various reports for a season, game type, and category for all 
 #' the skaters by game
-#' 
-#' `skater_game_report()` scrapes various reports for a given set of 
-#' `season`, `game_type`, and `category` for all the skaters by game.
-#' 
+#'
+#' `skater_game_report()` retrieves various reports for a season, game type, and category for all the skaters by game as a `data.frame` where each row represents game per player and includes detail on game timeline state, period/clock progression, and matchup flow, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @inheritParams skater_season_report
+#'
 #' @returns data.frame with one row per game per player
 #' @examples
 #' # May take >5s, so skip.
@@ -119,7 +121,7 @@ skater_game_report <- function(
         )$data
       } else {
         seasons_tbl <- seasons()
-        season_row  <- seasons_tbl[seasons_tbl$id == season, ]
+        season_row  <- seasons_tbl[seasons_tbl$seasonId == season, ]
         if (!nrow(season_row)) {
           stop('No season metadata found for season: ', season)
         }
@@ -169,7 +171,10 @@ skater_game_report <- function(
       if (!nrow(report)) {
         return(report)
       }
-      report[order(report$playerId, report$gameId), ]
+      report <- report[order(report$playerId, report$gameId), ]
+      names(report)[names(report) == 'lastName'] <- 'skaterLastName'
+      names(report) <- normalize_team_abbrev_cols(names(report))
+      report
     },
     error = function(e) {
       message('Invalid argument(s); refer to help file.')
@@ -179,9 +184,9 @@ skater_game_report <- function(
 }
 
 #' Access the career statistics for all the skaters
-#' 
-#' `skater_statistics()` scrapes the career statistics for all the skaters.
-#' 
+#'
+#' `skater_statistics()` retrieves the career statistics for all the skaters as a `data.frame` where each row represents player and includes detail on player identity, role, handedness, and biographical profile plus production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' skater_stats <- skater_statistics()
@@ -194,6 +199,9 @@ skater_statistics <- function() {
       type = 'r'
     )$data
     stats$id <- NULL
+    names(stats)[names(stats) == 'firstName'] <- 'skaterFirstName'
+    names(stats)[names(stats) == 'lastName']  <- 'skaterLastName'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
     stats[order(stats$playerId), ]
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
@@ -209,10 +217,9 @@ skater_stats <- function() {
 }
 
 #' Access the career regular season statistics for all the skaters
-#' 
-#' `skater_regular_statistics()` scrapes the career regular season statistics 
-#' for all the skaters.
-#' 
+#'
+#' `skater_regular_statistics()` retrieves the career regular season statistics for all the skaters as a `data.frame` where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' skater_regular_stats <- skater_regular_statistics()
@@ -220,10 +227,15 @@ skater_stats <- function() {
 
 skater_regular_statistics <- function() {
   tryCatch({
-    nhl_api(
+    stats    <- nhl_api(
       path = 'skater-career-scoring-regular-season',
       type = 'r'
     )$data
+    stats$id <- NULL
+    names(stats)[names(stats) == 'firstName'] <- 'skaterFirstName'
+    names(stats)[names(stats) == 'lastName']  <- 'skaterLastName'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
+    stats
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -238,10 +250,9 @@ skater_regular_stats <- function() {
 }
 
 #' Access the career playoff statistics for all the skaters
-#' 
-#' `skater_playoff_statistics()` scrapes the career playoff statistics for all 
-#' the skaters.
-#' 
+#'
+#' `skater_playoff_statistics()` retrieves the career playoff statistics for all the skaters as a `data.frame` where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' skater_playoff_stats <- skater_playoff_statistics()
@@ -249,10 +260,15 @@ skater_regular_stats <- function() {
 
 skater_playoff_statistics <- function() {
   tryCatch({
-    nhl_api(
+    stats    <- nhl_api(
       path = 'skater-career-scoring-playoffs',
       type = 'r'
     )$data
+    stats$id <- NULL
+    names(stats)[names(stats) == 'firstName'] <- 'skaterFirstName'
+    names(stats)[names(stats) == 'lastName']  <- 'skaterLastName'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
+    stats
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -267,10 +283,9 @@ skater_playoff_stats <- function() {
 }
 
 #' Access the statistics for all the skaters by season, game type, and team
-#' 
-#' `skater_season_statistics()` scrapes the statistics for all the skaters by 
-#' season, game type, and team.
-#' 
+#'
+#' `skater_season_statistics()` retrieves the statistics for all the skaters by season, game type, and team as a `data.frame` where each row represents player per season per game type, separated by team if applicable and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.
+#'
 #' @returns data.frame with one row per player per season per game type, 
 #' separated by team if applicable
 #' @examples
@@ -285,7 +300,12 @@ skater_season_statistics <- function() {
       type = 'r'
     )$data
     stats$`id.db:SEQUENCENO` <- NULL
-    stats[order(stats$`id.db:PLAYERID`, stats$`id.db:SEASON`), ]
+    stats <- stats[order(stats$`id.db:PLAYERID`, stats$`id.db:SEASON`), ]
+    names(stats)[names(stats) == 'id.db:PLAYERID'] <- 'playerId'
+    names(stats)[names(stats) == 'id.db:TEAMID']   <- 'teamId'
+    names(stats)[names(stats) == 'id.db:SEASON']   <- 'seasonId'
+    names(stats)[names(stats) == 'id.db:GAMETYPE'] <- 'gameTypeId'
+    stats
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
@@ -300,10 +320,9 @@ skater_season_stats <- function() {
 }
 
 #' Access the playoff statistics for all the skaters by series
-#' 
-#' `skater_series_statistics()` scrapes the playoff statistics for all the 
-#' skaters by series.
-#' 
+#'
+#' `skater_series_statistics()` retrieves the playoff statistics for all the skaters by series as a `data.frame` where each row represents player per series and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.
+#'
 #' @returns data.frame with one row per player per series
 #' @examples
 #' # May take >5s, so skip.
@@ -317,6 +336,9 @@ skater_series_statistics <- function() {
       type = 'r'
     )$data
     stats$id <- NULL
+    names(stats)[names(stats) == 'firstName'] <- 'skaterFirstName'
+    names(stats)[names(stats) == 'lastName']  <- 'skaterLastName'
+    names(stats) <- normalize_team_abbrev_cols(names(stats))
     stats
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
@@ -332,15 +354,15 @@ skater_series_stats <- function() {
 }
 
 #' Access the skater statistics leaders for a season, game type, and category
-#' 
-#' `skater_leaders()` scrapes the skater statistics leaders for a given set of 
-#' `season`, `game_type`, and `category`.
-#' 
+#'
+#' `skater_leaders()` retrieves the skater statistics leaders for a season, game type, and category as a `data.frame` where each row represents player and includes detail on player identity, role, handedness, and biographical profile.
+#'
 #' @inheritParams roster_statistics
 #' @param category string of 'a'/'assists', 'g'/goals', 
 #' 'shg'/'shorthanded goals', 'ppg'/'powerplay goals', 'p'/'points', 
 #' 'pim'/penalty minutes'/'penalty infraction minutes', 'toi'/'time on ice', 
 #' 'pm'/'plus minus', or 'f'/'faceoffs'
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' TOI_leaders_regular_20242025 <- skater_leaders(
@@ -379,10 +401,16 @@ skater_leaders <- function(
         f                            = 'faceoffLeaders',
         faceoffs                     = 'faceoffLeaders'
       )
-      nhl_api(
+      skaters <- nhl_api(
         path  = sprintf('v1/skater-stats-leaders/%s/%s', season, game_type),
         type  = 'w'
       )[[category]]
+      names(skaters)[names(skaters) == 'id']       <- 'playerId'
+      names(skaters)[names(skaters) == 'position'] <- 'positionCode'
+      names(skaters) <- normalize_locale_names(names(skaters))
+      names(skaters) <- scope_person_name_cols(names(skaters), 'skater')
+      names(skaters) <- normalize_team_abbrev_cols(names(skaters))
+      skaters
     },
     error = function(e) {
       message('Invalid argument(s); refer to help file.')
@@ -392,9 +420,9 @@ skater_leaders <- function(
 }
 
 #' Access the skaters on milestone watch
-#' 
-#' `skater_milestones()` scrapes the skaters on milestone watch.
-#' 
+#'
+#' `skater_milestones()` retrieves the skaters on milestone watch as a `data.frame` where each row represents player and includes detail on date/season filtering windows and chronological context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
+#'
 #' @returns data.frame with one row per player
 #' @examples
 #' skater_milestones <- skater_milestones()
@@ -402,10 +430,15 @@ skater_leaders <- function(
 
 skater_milestones <- function() {
   tryCatch({
-    nhl_api(
+    milestones <- nhl_api(
       path = 'en/milestones/skaters',
       type = 's'
     )$data
+    milestones$id <- NULL
+    names(milestones)[names(milestones) == 'firstName'] <- 'skaterFirstName'
+    names(milestones)[names(milestones) == 'lastName']  <- 'skaterLastName'
+    names(milestones) <- normalize_team_abbrev_cols(names(milestones))
+    milestones
   }, error = function(e) {
     message('Unable to create connection; please try again later.')
     data.frame()
