@@ -1,10 +1,10 @@
-test_that('game_rosters() returns non-empty data.frame', {
+test_that("game_rosters() returns non-empty data.frame", {
   skip_if_offline()
   test <- game_rosters()
   expect_true(is.data.frame(test) && nrow(test) > 0)
 })
 
-test_that('game_rosters(0) returns message and empty data.frame', {
+test_that("game_rosters(0) returns message and empty data.frame", {
   skip_if_offline()
   expect_message(
     test <- game_rosters(0),
