@@ -1,10 +1,10 @@
-test_that('gc_summary() returns non-empty list', {
+test_that("gc_summary() returns non-empty list", {
   skip_if_offline()
   test <- gc_summary()
   expect_true(is.list(test) && length(test) > 0)
 })
 
-test_that('gc_summary(0) returns message and empty list', {
+test_that("gc_summary(0) returns message and empty list", {
   skip_if_offline()
   expect_message(
     test <- gc_summary(0),
