@@ -1,10 +1,10 @@
-test_that('roster(1, 20242025) returns non-empty data.frame', {
+test_that("roster(1, 20242025, 'forwards') returns non-empty data.frame", {
   skip_if_offline()
-  test <- roster(1, 20242025) 
+  test <- roster(1, 20242025, 'forwards')
   expect_true(is.data.frame(test) && nrow(test) > 0)
 })
 
-test_that('roster(0) returns message and empty data.frame', {
+test_that("roster(0) returns message and empty data.frame", {
   skip_if_offline()
   expect_message(
     test <- roster(0),
