@@ -1,9 +1,10 @@
-test_that('team_prospects() returns data.frame', {
+test_that("team_prospects() returns non-empty data.frame", {
   skip_if_offline()
-  expect_true(is.data.frame(team_prospects()))
+  test <- team_prospects()
+  expect_true(is.data.frame(test) && nrow(test) > 0)
 })
 
-test_that('team_prospects(0) returns message and empty data.frame', {
+test_that("team_prospects(0) returns message and empty data.frame", {
   skip_if_offline()
   expect_message(
     test <- team_prospects(0),
